Changelog
=========

0.2.7 (2018-01-15)
------------------

* logging_utilities now transaprently supports SQLAlchemy and optional
  coloring of HTTP logs

0.2.6 (2017-11-23)
------------------

* model_utilities.Representable is now customizeable using private class attrs.

0.2.5 (2017-11-16)
------------------

* Added file_utilities.switch_extension

0.2.4 (2017-11-16)
------------------

* Added file_utilities.silent_remove

0.2.3 (2017-11-04)
------------------

* Added all_subclasses function

0.2.2 (2017-10-25)
------------------

* Added backports of Python 3.4 `min` and `max`.

0.2.1 (2017-10-24)
------------------

* Added logging_utilities.log_to_console_for

0.2.0 (2017-10-06)
------------------

* Added SQL log coloring formatter (for Django logs)

0.1.1 (2017-10-02)
------------------

* DynamicContextFormatter now keeps context in thread local.

0.1.0 (2017-09-26)
------------------

* Initial release
